from setuptools import setup

setup(name='distributions_gl_cs',
      version='1.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_gl_cs'],
      author = "Gabriel Cantanhede",
      author_email = "gabriel.lcsilva@hotmail.com",
      zip_safe=False)
